@@ -2,14 +2,13 @@
 """
 对字典类型的日期支持
 """
-from copy import deepcopy
 from datetime import datetime
 
 from daypy.utils import pretty_unit
 
 
 def dict_support(option, Daypy, daypy):
-    oldParse = Daypy.parse
+    old_parse = Daypy.parse
 
     def parse_date(value):
         if not isinstance(value, dict):
@@ -30,6 +29,6 @@ def dict_support(option, Daypy, daypy):
 
     def parse(_, value=None, *args, **kwargs):
         dt = parse_date(value)
-        return oldParse(_, dt or value, *args, **kwargs)
+        return old_parse(_, dt or value, *args, **kwargs)
 
     Daypy.parse = parse
